Struct
QmiMessageLocInjectUtcTimeOutput
since: 1.37
Description [src]
struct QmiMessageLocInjectUtcTimeOutput {
/* No available fields */
}
The QmiMessageLocInjectUtcTimeOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.37
Instance methods
qmi_message_loc_inject_utc_time_output_ref
Atomically increments the reference count of self by one.
since: 1.37
qmi_message_loc_inject_utc_time_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.37